@@ -124,7 +124,7 @@ class Custom_Background {
 		}
 
 		if ( isset( $_POST['remove-background'] ) ) {
-			// @TODO: Uploaded files are not removed here.
+			// @todo Uploaded files are not removed here.
 			check_admin_referer( 'custom-background-remove', '_wpnonce-custom-background-remove' );
 			set_theme_mod( 'background_image', '' );
 			set_theme_mod( 'background_image_thumb', '' );
@@ -284,7 +284,7 @@ class Custom_Background {
 				. " background-attachment: $background_attachment;";
 			}
 			?>
-	<div id="custom-background-image" style="<?php echo $background_styles; ?>"><?php // must be double quote, see above ?>
+	<div id="custom-background-image" style="<?php echo $background_styles; ?>"><?php // Must be double quote, see above. ?>
 			<?php if ( $background_image_thumb ) { ?>
 		<img class="custom-background-image" src="<?php echo $background_image_thumb; ?>" style="visibility:hidden;" alt="" /><br />
 		<img class="custom-background-image" src="<?php echo $background_image_thumb; ?>" style="visibility:hidden;" alt="" />
@@ -503,7 +503,7 @@ class Custom_Background {
 		$file     = $file['file'];
 		$filename = wp_basename( $file );
 
-		// Construct the object array
+		// Construct the object array.
 		$object = array(
 			'post_title'     => $filename,
 			'post_content'   => $url,
@@ -512,10 +512,10 @@ class Custom_Background {
 			'context'        => 'custom-background',
 		);
 
-		// Save the data
+		// Save the data.
 		$id = wp_insert_attachment( $object, $file );
 
-		// Add the meta-data
+		// Add the metadata.
 		wp_update_attachment_metadata( $id, wp_generate_attachment_metadata( $id, $file ) );
 		update_post_meta( $id, '_wp_attachment_is_custom_background', get_option( 'stylesheet' ) );
 
@@ -525,7 +525,7 @@ class Custom_Background {
 		set_theme_mod( 'background_image_thumb', esc_url_raw( $thumbnail[0] ) );
 
 		/** This action is documented in wp-admin/includes/class-custom-image-header.php */
-		do_action( 'wp_create_file_in_uploads', $file, $id ); // For replication
+		do_action( 'wp_create_file_in_uploads', $file, $id ); // For replication.
 		$this->updated = true;
 	}
 
