@@ -293,15 +293,6 @@ jQuery( function ( $ ) {
 		img.src = akismet_mshot_url( linkUrl );
 	}
 
-	/**
-	 * Sets the comment form privacy notice display to hide when one clicks Core's dismiss button on the related admin notice.
-	 */
-	$( '#akismet-privacy-notice-admin-notice' ).on( 'click', '.notice-dismiss', function () {
-		$.ajax( {
-			url: './options-general.php?page=akismet-key-config&akismet_comment_form_privacy_notice=hide',
-		} );
-	});
-
 	$( '.akismet-could-be-primary' ).each( function () {
 		var form = $( this ).closest( 'form' );
 
