@@ -8,8 +8,8 @@
  *
  * @package WordPress
  * @subpackage Twenty_Seventeen
- * @since 1.0
- * @version 1.0
+ * @since Twenty Seventeen 1.0
+ * @version 1.2
  */
 
 ?>
@@ -21,19 +21,23 @@
 				<?php
 				get_template_part( 'template-parts/footer/footer', 'widgets' );
 
-				if ( has_nav_menu( 'social' ) ) : ?>
-					<nav class="social-navigation" role="navigation" aria-label="<?php _e( 'Footer Social Links Menu', 'twentyseventeen' ); ?>">
+				if ( has_nav_menu( 'social' ) ) :
+					?>
+					<nav class="social-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Footer Social Links Menu', 'twentyseventeen' ); ?>">
 						<?php
-							wp_nav_menu( array(
-								'theme_location' => 'social',
-								'menu_class'     => 'social-links-menu',
-								'depth'          => 1,
-								'link_before'    => '<span class="screen-reader-text">',
-								'link_after'     => '</span>' . twentyseventeen_get_svg( array( 'icon' => 'chain' ) ),
-							) );
+							wp_nav_menu(
+								array(
+									'theme_location' => 'social',
+									'menu_class'     => 'social-links-menu',
+									'depth'          => 1,
+									'link_before'    => '<span class="screen-reader-text">',
+									'link_after'     => '</span>' . twentyseventeen_get_svg( array( 'icon' => 'chain' ) ),
+								)
+							);
 						?>
 					</nav><!-- .social-navigation -->
-				<?php endif;
+					<?php
+				endif;
 
 				get_template_part( 'template-parts/footer/site', 'info' );
 				?>
