@@ -948,7 +948,7 @@ function wp_kses_split( $string, $allowed_html, $allowed_protocols ) {
 }
 
 /**
- * Helper function listing HTML attributes containing a URL.
+ * Returns an array of HTML attribute names whose value contains a URL.
  *
  * This function returns a list of all HTML attributes that must contain
  * a URL according to the HTML specification.
@@ -959,7 +959,7 @@ function wp_kses_split( $string, $allowed_html, $allowed_protocols ) {
  *
  * @since 5.0.1
  *
- * @return array HTML attributes that must include a URL.
+ * @return string[] HTML attribute names whose value contains a URL.
  */
 function wp_kses_uri_attributes() {
 	$uri_attributes = array(
@@ -990,7 +990,7 @@ function wp_kses_uri_attributes() {
 	 *
 	 * @since 5.0.1
 	 *
-	 * @param array $uri_attributes HTML attributes requiring validation as a URL.
+	 * @param string[] $uri_attributes HTML attribute names whose value contains a URL.
 	 */
 	$uri_attributes = apply_filters( 'wp_kses_uri_attributes', $uri_attributes );
 
@@ -1046,15 +1046,15 @@ function wp_kses_split2( $string, $allowed_html, $allowed_protocols ) {
 	// Allow HTML comments.
 	if ( '<!--' == substr( $string, 0, 4 ) ) {
 		$string = str_replace( array( '<!--', '-->' ), '', $string );
-		while ( $string != ( $newstring = wp_kses( $string, $allowed_html, $allowed_protocols ) ) ) {
+		while ( ( $newstring = wp_kses( $string, $allowed_html, $allowed_protocols ) ) != $string ) {
 			$string = $newstring;
 		}
-		if ( $string == '' ) {
+		if ( '' == $string ) {
 			return '';
 		}
-		// prevent multiple dashes in comments
+		// Prevent multiple dashes in comments.
 		$string = preg_replace( '/--+/', '-', $string );
-		// prevent three dashes closing a comment
+		// Prevent three dashes closing a comment.
 		$string = preg_replace( '/-$/', '', $string );
 		return "<!--{$string}-->";
 	}
@@ -1078,7 +1078,7 @@ function wp_kses_split2( $string, $allowed_html, $allowed_protocols ) {
 	}
 
 	// No attributes are allowed for closing elements.
-	if ( $slash != '' ) {
+	if ( '' != $slash ) {
 		return "</$elem>";
 	}
 
@@ -1119,11 +1119,11 @@ function wp_kses_attr( $element, $attr, $allowed_html, $allowed_protocols ) {
 		return "<$element$xhtml_slash>";
 	}
 
-	// Split it
+	// Split it.
 	$attrarr = wp_kses_hair( $attr, $allowed_protocols );
 
 	// Go through $attrarr, and save the allowed attributes for this element
-	// in $attr2
+	// in $attr2.
 	$attr2 = '';
 	foreach ( $attrarr as $arreach ) {
 		if ( wp_kses_attr_check( $arreach['name'], $arreach['value'], $arreach['whole'], $arreach['vless'], $element, $allowed_html ) ) {
@@ -1131,7 +1131,7 @@ function wp_kses_attr( $element, $attr, $allowed_html, $allowed_protocols ) {
 		}
 	}
 
-	// Remove any "<" or ">" characters
+	// Remove any "<" or ">" characters.
 	$attr2 = preg_replace( '/[<>]/', '', $attr2 );
 
 	return "<$element$attr2$xhtml_slash>";
@@ -1152,9 +1152,18 @@ function wp_kses_attr( $element, $attr, $allowed_html, $allowed_protocols ) {
  * @return bool Whether or not the attribute is allowed.
  */
 function wp_kses_attr_check( &$name, &$value, &$whole, $vless, $element, $allowed_html ) {
-	$allowed_attr = $allowed_html[ strtolower( $element ) ];
+	$name_low    = strtolower( $name );
+	$element_low = strtolower( $element );
+
+	if ( ! isset( $allowed_html[ $element_low ] ) ) {
+		$name  = '';
+		$value = '';
+		$whole = '';
+		return false;
+	}
+
+	$allowed_attr = $allowed_html[ $element_low ];
 
-	$name_low = strtolower( $name );
 	if ( ! isset( $allowed_attr[ $name_low ] ) || '' == $allowed_attr[ $name_low ] ) {
 		/*
 		 * Allow `data-*` attributes.
@@ -1173,7 +1182,9 @@ function wp_kses_attr_check( &$name, &$value, &$whole, $vless, $element, $allowe
 			 */
 			$allowed_attr[ $match[0] ] = $allowed_attr['data-*'];
 		} else {
-			$name = $value = $whole = '';
+			$name  = '';
+			$value = '';
+			$whole = '';
 			return false;
 		}
 	}
@@ -1182,7 +1193,9 @@ function wp_kses_attr_check( &$name, &$value, &$whole, $vless, $element, $allowe
 		$new_value = safecss_filter_attr( $value );
 
 		if ( empty( $new_value ) ) {
-			$name = $value = $whole = '';
+			$name  = '';
+			$value = '';
+			$whole = '';
 			return false;
 		}
 
@@ -1191,10 +1204,12 @@ function wp_kses_attr_check( &$name, &$value, &$whole, $vless, $element, $allowe
 	}
 
 	if ( is_array( $allowed_attr[ $name_low ] ) ) {
-		// there are some checks
+		// There are some checks.
 		foreach ( $allowed_attr[ $name_low ] as $currkey => $currval ) {
 			if ( ! wp_kses_check_attr_val( $value, $vless, $currkey, $currval ) ) {
-				$name = $value = $whole = '';
+				$name  = '';
+				$value = '';
+				$whole = '';
 				return false;
 			}
 		}
@@ -1226,7 +1241,7 @@ function wp_kses_hair( $attr, $allowed_protocols ) {
 	$attrname = '';
 	$uris     = wp_kses_uri_attributes();
 
-	// Loop through the whole attribute list
+	// Loop through the whole attribute list.
 
 	while ( strlen( $attr ) != 0 ) {
 		$working = 0; // Was the last operation successful?
@@ -1235,21 +1250,22 @@ function wp_kses_hair( $attr, $allowed_protocols ) {
 			case 0:
 				if ( preg_match( '/^([-a-zA-Z:]+)/', $attr, $match ) ) {
 					$attrname = $match[1];
-					$working  = $mode = 1;
+					$working  = 1;
+					$mode     = 1;
 					$attr     = preg_replace( '/^[-a-zA-Z:]+/', '', $attr );
 				}
 
 				break;
 
 			case 1:
-				if ( preg_match( '/^\s*=\s*/', $attr ) ) { // equals sign
+				if ( preg_match( '/^\s*=\s*/', $attr ) ) { // Equals sign.
 					$working = 1;
 					$mode    = 2;
 					$attr    = preg_replace( '/^\s*=\s*/', '', $attr );
 					break;
 				}
 
-				if ( preg_match( '/^\s+/', $attr ) ) { // valueless
+				if ( preg_match( '/^\s+/', $attr ) ) { // Valueless.
 					$working = 1;
 					$mode    = 0;
 					if ( false === array_key_exists( $attrname, $attrarr ) ) {
@@ -1330,17 +1346,17 @@ function wp_kses_hair( $attr, $allowed_protocols ) {
 				}
 
 				break;
-		} // switch
+		} // End switch.
 
-		if ( $working == 0 ) { // not well formed, remove and try again
+		if ( 0 == $working ) { // Not well-formed, remove and try again.
 			$attr = wp_kses_html_error( $attr );
 			$mode = 0;
 		}
-	} // while
+	} // End while.
 
-	if ( $mode == 1 && false === array_key_exists( $attrname, $attrarr ) ) {
-		// special case, for when the attribute list ends with a valueless
-		// attribute like "selected"
+	if ( 1 == $mode && false === array_key_exists( $attrname, $attrarr ) ) {
+		// Special case, for when the attribute list ends with a valueless
+		// attribute like "selected".
 		$attrarr[ $attrname ] = array(
 			'name'  => $attrname,
 			'value' => '',
@@ -1389,7 +1405,7 @@ function wp_kses_attr_parse( $element ) {
 		$xhtml_slash = '';
 	}
 
-	// Split it
+	// Split it.
 	$attrarr = wp_kses_hair_parse( $attr );
 	if ( false === $attrarr ) {
 		return false;
@@ -1428,14 +1444,14 @@ function wp_kses_hair_parse( $attr ) {
 	.     '\[\[?[^\[\]]+\]\]?' // Shortcode in the name position implies unfiltered_html.
 	. ')'
 	. '(?:'               // Attribute value.
-	.     '\s*=\s*'       // All values begin with '='
+	.     '\s*=\s*'       // All values begin with '='.
 	.     '(?:'
-	.         '"[^"]*"'   // Double-quoted
+	.         '"[^"]*"'   // Double-quoted.
 	.     '|'
-	.         "'[^']*'"   // Single-quoted
+	.         "'[^']*'"   // Single-quoted.
 	.     '|'
-	.         '[^\s"\']+' // Non-quoted
-	.         '(?:\s|$)'  // Must have a space
+	.         '[^\s"\']+' // Non-quoted.
+	.         '(?:\s|$)'  // Must have a space.
 	.     ')'
 	. '|'
 	.     '(?:\s|$)'      // If attribute has no value, space is required.
@@ -1476,9 +1492,11 @@ function wp_kses_check_attr_val( $value, $vless, $checkname, $checkvalue ) {
 
 	switch ( strtolower( $checkname ) ) {
 		case 'maxlen':
-			// The maxlen check makes sure that the attribute value has a length not
-			// greater than the given value. This can be used to avoid Buffer Overflows
-			// in WWW clients and various Internet servers.
+			/*
+			 * The maxlen check makes sure that the attribute value has a length not
+			 * greater than the given value. This can be used to avoid Buffer Overflows
+			 * in WWW clients and various Internet servers.
+			 */
 
 			if ( strlen( $value ) > $checkvalue ) {
 				$ok = false;
@@ -1486,8 +1504,10 @@ function wp_kses_check_attr_val( $value, $vless, $checkname, $checkvalue ) {
 			break;
 
 		case 'minlen':
-			// The minlen check makes sure that the attribute value has a length not
-			// smaller than the given value.
+			/*
+			 * The minlen check makes sure that the attribute value has a length not
+			 * smaller than the given value.
+			 */
 
 			if ( strlen( $value ) < $checkvalue ) {
 				$ok = false;
@@ -1495,11 +1515,13 @@ function wp_kses_check_attr_val( $value, $vless, $checkname, $checkvalue ) {
 			break;
 
 		case 'maxval':
-			// The maxval check does two things: it checks that the attribute value is
-			// an integer from 0 and up, without an excessive amount of zeroes or
-			// whitespace (to avoid Buffer Overflows). It also checks that the attribute
-			// value is not greater than the given value.
-			// This check can be used to avoid Denial of Service attacks.
+			/*
+			 * The maxval check does two things: it checks that the attribute value is
+			 * an integer from 0 and up, without an excessive amount of zeroes or
+			 * whitespace (to avoid Buffer Overflows). It also checks that the attribute
+			 * value is not greater than the given value.
+			 * This check can be used to avoid Denial of Service attacks.
+			 */
 
 			if ( ! preg_match( '/^\s{0,6}[0-9]{1,6}\s{0,6}$/', $value ) ) {
 				$ok = false;
@@ -1510,8 +1532,10 @@ function wp_kses_check_attr_val( $value, $vless, $checkname, $checkvalue ) {
 			break;
 
 		case 'minval':
-			// The minval check makes sure that the attribute value is a positive integer,
-			// and that it is not smaller than the given value.
+			/*
+			 * The minval check makes sure that the attribute value is a positive integer,
+			 * and that it is not smaller than the given value.
+			 */
 
 			if ( ! preg_match( '/^\s{0,6}[0-9]{1,6}\s{0,6}$/', $value ) ) {
 				$ok = false;
@@ -1522,16 +1546,18 @@ function wp_kses_check_attr_val( $value, $vless, $checkname, $checkvalue ) {
 			break;
 
 		case 'valueless':
-			// The valueless check makes sure if the attribute has a value
-			// (like `<a href="blah">`) or not (`<option selected>`). If the given value
-			// is a "y" or a "Y", the attribute must not have a value.
-			// If the given value is an "n" or an "N", the attribute must have a value.
+			/*
+			 * The valueless check makes sure if the attribute has a value
+			 * (like `<a href="blah">`) or not (`<option selected>`). If the given value
+			 * is a "y" or a "Y", the attribute must not have a value.
+			 * If the given value is an "n" or an "N", the attribute must have a value.
+			 */
 
 			if ( strtolower( $checkvalue ) != $vless ) {
 				$ok = false;
 			}
 			break;
-	} // switch
+	} // End switch.
 
 	return $ok;
 }
@@ -1658,7 +1684,7 @@ function wp_kses_html_error( $string ) {
  */
 function wp_kses_bad_protocol_once( $string, $allowed_protocols, $count = 1 ) {
 	$string  = preg_replace( '/(&#0*58(?![;0-9])|&#x0*3a(?![;a-f0-9]))/i', '$1;', $string );
-	$string2 = preg_split( '/:|&#0*58;|&#x0*3a;/i', $string, 2 );
+	$string2 = preg_split( '/:|&#0*58;|&#x0*3a;|&colon;/i', $string, 2 );
 	if ( isset( $string2[1] ) && ! preg_match( '%/\?%', $string2[0] ) ) {
 		$string   = trim( $string2[1] );
 		$protocol = wp_kses_bad_protocol_once2( $string2[0], $allowed_protocols );
@@ -1727,7 +1753,7 @@ function wp_kses_normalize_entities( $string ) {
 	// Disarm all entities by converting & to &amp;
 	$string = str_replace( '&', '&amp;', $string );
 
-	// Change back the allowed entities in our entity whitelist
+	// Change back the allowed entities in our entity whitelist.
 	$string = preg_replace_callback( '/&amp;([A-Za-z]{2,8}[0-9]{0,2});/', 'wp_kses_named_entities', $string );
 	$string = preg_replace_callback( '/&amp;#(0*[0-9]{1,7});/', 'wp_kses_normalize_entities2', $string );
 	$string = preg_replace_callback( '/&amp;#[Xx](0*[0-9A-Fa-f]{1,6});/', 'wp_kses_normalize_entities3', $string );
@@ -1819,10 +1845,10 @@ function wp_kses_normalize_entities3( $matches ) {
  * @return bool Whether or not the codepoint is a valid Unicode codepoint.
  */
 function valid_unicode( $i ) {
-	return ( $i == 0x9 || $i == 0xa || $i == 0xd ||
-			( $i >= 0x20 && $i <= 0xd7ff ) ||
-			( $i >= 0xe000 && $i <= 0xfffd ) ||
-			( $i >= 0x10000 && $i <= 0x10ffff ) );
+	return ( 0x9 == $i || 0xa == $i || 0xd == $i ||
+			( 0x20 <= $i && $i <= 0xd7ff ) ||
+			( 0xe000 <= $i && $i <= 0xfffd ) ||
+			( 0x10000 <= $i && $i <= 0x10ffff ) );
 }
 
 /**
@@ -1975,17 +2001,17 @@ function wp_filter_nohtml_kses( $data ) {
  * @since 2.0.0
  */
 function kses_init_filters() {
-	// Normal filtering
+	// Normal filtering.
 	add_filter( 'title_save_pre', 'wp_filter_kses' );
 
-	// Comment filtering
+	// Comment filtering.
 	if ( current_user_can( 'unfiltered_html' ) ) {
 		add_filter( 'pre_comment_content', 'wp_filter_post_kses' );
 	} else {
 		add_filter( 'pre_comment_content', 'wp_filter_kses' );
 	}
 
-	// Post filtering
+	// Post filtering.
 	add_filter( 'content_save_pre', 'wp_filter_post_kses' );
 	add_filter( 'excerpt_save_pre', 'wp_filter_post_kses' );
 	add_filter( 'content_filtered_save_pre', 'wp_filter_post_kses' );
@@ -2004,14 +2030,14 @@ function kses_init_filters() {
  * @since 2.0.6
  */
 function kses_remove_filters() {
-	// Normal filtering
+	// Normal filtering.
 	remove_filter( 'title_save_pre', 'wp_filter_kses' );
 
-	// Comment filtering
+	// Comment filtering.
 	remove_filter( 'pre_comment_content', 'wp_filter_post_kses' );
 	remove_filter( 'pre_comment_content', 'wp_filter_kses' );
 
-	// Post filtering
+	// Post filtering.
 	remove_filter( 'content_save_pre', 'wp_filter_post_kses' );
 	remove_filter( 'excerpt_save_pre', 'wp_filter_post_kses' );
 	remove_filter( 'content_filtered_save_pre', 'wp_filter_post_kses' );
@@ -2045,7 +2071,7 @@ function kses_init() {
  */
 function safecss_filter_attr( $css, $deprecated = '' ) {
 	if ( ! empty( $deprecated ) ) {
-		_deprecated_argument( __FUNCTION__, '2.8.1' ); // Never implemented
+		_deprecated_argument( __FUNCTION__, '2.8.1' ); // Never implemented.
 	}
 
 	$css = wp_kses_no_null( $css );
@@ -2064,6 +2090,9 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 	 * @since 5.0.0 Added support for `background-image`.
 	 * @since 5.1.0 Added support for `text-transform`.
 	 * @since 5.2.0 Added support for `background-position` and `grid-template-columns`
+	 * @since 5.3.0 Added support for `grid`, `flex` and `column` layout properties.
+	 *              Extend `background-*` support of individual properties.
+	 * @since 5.3.1 Added support for gradient backgrounds.
 	 *
 	 * @param string[] $attr Array of allowed CSS attributes.
 	 */
@@ -2074,8 +2103,12 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 			'background-color',
 			'background-image',
 			'background-position',
+			'background-size',
+			'background-attachment',
+			'background-blend-mode',
 
 			'border',
+			'border-radius',
 			'border-width',
 			'border-color',
 			'border-style',
@@ -2100,6 +2133,14 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 			'border-collapse',
 			'caption-side',
 
+			'columns',
+			'column-count',
+			'column-fill',
+			'column-gap',
+			'column-rule',
+			'column-span',
+			'column-width',
+
 			'color',
 			'font',
 			'font-family',
@@ -2134,6 +2175,32 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 			'padding-left',
 			'padding-top',
 
+			'flex',
+			'flex-basis',
+			'flex-direction',
+			'flex-flow',
+			'flex-grow',
+			'flex-shrink',
+
+			'grid-template-columns',
+			'grid-auto-columns',
+			'grid-column-start',
+			'grid-column-end',
+			'grid-column-gap',
+			'grid-template-rows',
+			'grid-auto-rows',
+			'grid-row-start',
+			'grid-row-end',
+			'grid-row-gap',
+			'grid-gap',
+
+			'justify-content',
+			'justify-items',
+			'justify-self',
+			'align-content',
+			'align-items',
+			'align-self',
+
 			'clear',
 			'cursor',
 			'direction',
@@ -2141,7 +2208,6 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 			'overflow',
 			'vertical-align',
 			'list-style-type',
-			'grid-template-columns',
 		)
 	);
 
@@ -2163,13 +2229,22 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 		'list-style-image',
 	);
 
+	/*
+	 * CSS attributes that accept gradient data types.
+	 *
+	 */
+	$css_gradient_data_types = array(
+		'background',
+		'background-image',
+	);
+
 	if ( empty( $allowed_attr ) ) {
 		return $css;
 	}
 
 	$css = '';
 	foreach ( $css_array as $css_item ) {
-		if ( $css_item == '' ) {
+		if ( '' == $css_item ) {
 			continue;
 		}
 
@@ -2177,6 +2252,7 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 		$css_test_string = $css_item;
 		$found           = false;
 		$url_attr        = false;
+		$gradient_attr   = false;
 
 		if ( strpos( $css_item, ':' ) === false ) {
 			$found = true;
@@ -2185,8 +2261,9 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 			$css_selector = trim( $parts[0] );
 
 			if ( in_array( $css_selector, $allowed_attr, true ) ) {
-				$found    = true;
-				$url_attr = in_array( $css_selector, $css_url_data_types, true );
+				$found         = true;
+				$url_attr      = in_array( $css_selector, $css_url_data_types, true );
+				$gradient_attr = in_array( $css_selector, $css_gradient_data_types, true );
 			}
 		}
 
@@ -2205,7 +2282,7 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 
 				$url = trim( $url_pieces[2] );
 
-				if ( empty( $url ) || $url !== wp_kses_bad_protocol( $url, $allowed_protocols ) ) {
+				if ( empty( $url ) || wp_kses_bad_protocol( $url, $allowed_protocols ) !== $url ) {
 					$found = false;
 					break;
 				} else {
@@ -2215,9 +2292,17 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 			}
 		}
 
+		if ( $found && $gradient_attr ) {
+			$css_value = trim( $parts[1] );
+			if ( preg_match( '/^(repeating-)?(linear|radial|conic)-gradient\(([^()]|rgb[a]?\([^()]*\))*\)$/', $css_value ) ) {
+				// Remove the whole `gradient` bit that was matched above from the CSS.
+				$css_test_string = str_replace( $css_value, '', $css_test_string );
+			}
+		}
+
 		// Remove any CSS containing containing \ ( & } = or comments, except for url() useage checked above.
 		if ( $found && ! preg_match( '%[\\\(&=}]|/\*%', $css_test_string ) ) {
-			if ( $css != '' ) {
+			if ( '' != $css ) {
 				$css .= ';';
 			}
 
