@@ -10,7 +10,11 @@
  */
 
 /**
- * Check if post has an image attached.
+ * Determines whether a post has an image attached.
+ *
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
+ * Conditional Tags} article in the Theme Developer Handbook.
  *
  * @since 2.9.0
  * @since 4.4.0 `$post` can be a post ID or WP_Post object.
@@ -19,7 +23,19 @@
  * @return bool Whether the post has an image attached.
  */
 function has_post_thumbnail( $post = null ) {
-	return (bool) get_post_thumbnail_id( $post );
+	$thumbnail_id  = get_post_thumbnail_id( $post );
+	$has_thumbnail = (bool) $thumbnail_id;
+
+	/**
+	 * Filters whether a post has a post thumbnail.
+	 *
+	 * @since 5.1.0
+	 *
+	 * @param bool             $has_thumbnail true if the post has a post thumbnail, otherwise false.
+	 * @param int|WP_Post|null $post          Post ID or WP_Post object. Default is global `$post`.
+	 * @param int|string       $thumbnail_id  Post thumbnail ID or empty string.
+	 */
+	return (bool) apply_filters( 'has_post_thumbnail', $has_thumbnail, $post, $thumbnail_id );
 }
 
 /**
@@ -29,14 +45,14 @@ function has_post_thumbnail( $post = null ) {
  * @since 4.4.0 `$post` can be a post ID or WP_Post object.
  *
  * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
- * @return string|int Post thumbnail ID or empty string.
+ * @return int|string Post thumbnail ID or empty string if the post does not exist.
  */
 function get_post_thumbnail_id( $post = null ) {
 	$post = get_post( $post );
 	if ( ! $post ) {
 		return '';
 	}
-	return get_post_meta( $post->ID, '_thumbnail_id', true );
+	return (int) get_post_meta( $post->ID, '_thumbnail_id', true );
 }
 
 /**
@@ -67,24 +83,28 @@ function the_post_thumbnail( $size = 'post-thumbnail', $attr = '' ) {
  *
  * @since 3.2.0
  *
- * @global WP_Query $wp_query
+ * @global WP_Query $wp_query WordPress Query object.
  *
  * @param WP_Query $wp_query Optional. A WP_Query instance. Defaults to the $wp_query global.
  */
 function update_post_thumbnail_cache( $wp_query = null ) {
-	if ( ! $wp_query )
+	if ( ! $wp_query ) {
 		$wp_query = $GLOBALS['wp_query'];
+	}
 
-	if ( $wp_query->thumbnails_cached )
+	if ( $wp_query->thumbnails_cached ) {
 		return;
+	}
 
 	$thumb_ids = array();
 	foreach ( $wp_query->posts as $post ) {
-		if ( $id = get_post_thumbnail_id( $post->ID ) )
+		$id = get_post_thumbnail_id( $post->ID );
+		if ( $id ) {
 			$thumb_ids[] = $id;
+		}
 	}
 
-	if ( ! empty ( $thumb_ids ) ) {
+	if ( ! empty( $thumb_ids ) ) {
 		_prime_post_caches( $thumb_ids, false, true );
 	}
 
@@ -122,11 +142,13 @@ function get_the_post_thumbnail( $post = null, $size = 'post-thumbnail', $attr =
 	 * Filters the post thumbnail size.
 	 *
 	 * @since 2.9.0
+	 * @since 4.9.0 Added the `$post_id` parameter.
 	 *
-	 * @param string|array $size The post thumbnail size. Image size or array of width and height
-	 *                           values (in that order). Default 'post-thumbnail'.
+	 * @param string|array $size    The post thumbnail size. Image size or array of width and height
+	 *                              values (in that order). Default 'post-thumbnail'.
+	 * @param int          $post_id The post ID.
 	 */
-	$size = apply_filters( 'post_thumbnail_size', $size );
+	$size = apply_filters( 'post_thumbnail_size', $size, $post->ID );
 
 	if ( $post_thumbnail_id ) {
 
@@ -143,8 +165,9 @@ function get_the_post_thumbnail( $post = null, $size = 'post-thumbnail', $attr =
 		 *                                        and height values (in that order). Default 'post-thumbnail'.
 		 */
 		do_action( 'begin_fetch_post_thumbnail_html', $post->ID, $post_thumbnail_id, $size );
-		if ( in_the_loop() )
+		if ( in_the_loop() ) {
 			update_post_thumbnail_cache();
+		}
 		$html = wp_get_attachment_image( $post_thumbnail_id, $size, false, $attr );
 
 		/**
